\name{edira}
\alias{edira}
\title{Externally Centered Correlation Coefficient and Wilcoxon Test for Equally Directed Abnormalities}
\description{
Calculates the externally centered correlation coefficient and performs a Wilcoxon test for equally directed abnormalities of two variables (e.g., gene expression and copy number intensities) between a patient and a reference collective.
}
\usage{
edira(A, B, A_ref, B_ref)
}

\arguments{
  \item{A}{list containing data and annotations of variable A for a patient collective. See 'Details' for format.}
  \item{B}{list containing data and annotations of variable B for the same patient collective represented in \code{A_data}. See 'Details' for format.}
  \item{A_ref}{list containing data and annotations of variable A for a reference collective. See 'Details' for format.}
  \item{B_ref}{list containing data and annotations of variable B for a reference collective. See 'Details' for format.}
}
\details{
\code{A} and \code{B} represent a single patient collective to be analyzed. Both must be a list containing a data frame 'data' in which each column contains the data for an individual contained in this collective, and a data frame 'info'
which has a column "chromosome" containing the chromosome number and a column "position" that contains the (middle) position of each measured locus (e.g., probe set) as a single value.
\code{A_ref} and \code{B_ref} represent reference collectives for variables A and B. Ideally, but not necessarily, they stem from a single reference collective.
\code{A_ref} and \code{B_ref} must have the same structure as \code{A} and \code{B}.

IMPORTANT: The rows of both the data and info object must be in increasing order of chromosomes and, within chromosomes, of positions.

The measurements in \code{A$data} and \code{A_ref$data} as well as \code{B$data} and \code{B_ref$data} should be obtained under the same laboratory conditions, respectively.

For sensible results, all measurements have to be preprocessed previously (e.g., normalized).
}
\value{
A list is returned containing the following information for each locus:

  \item{chromosome}{chromosome number.}
  \item{position}{(middle) position.}
  \item{eccc}{value of the externally centered correlation coefficient.}
  \item{eccc_var}{value of a variant of the externally centered correlation coefficient for which the centering in the denominator is done by
  the medians of the patient collective instead of the reference collective.}
  \item{test}{p-value of the Wilcoxon test for equally directed abnormalities of A and B in the patients compared to the reference collective.}
  \item{quadrant}{quadrant of the median patients' A and B values in the biplot of A and B. Quadrant here is to be understood with respect to the axes defined by the medians of A and B in the reference collective.}
}
\references{Schaefer, M., Schwender, H., Merk, S., Haferlach, C., Ickstadt, K., Dugas, M. (2009), Integrated analysis of copy number alterations and gene expression:
A bivariate assessment of equally directed abnormalities, Bioinformatics 25(24), 3228  3235.
}
\note{If the medians of the patient and the reference collective are equal for both of the variables, the corresponding quadrant is determined by sampling.

Copy number data may be processed by a segmentation algorithm to denoise measurements and obtain values that can be assigned directly to data points of
a second data type, e.g., gene expression. The function \code{segmentCN} can be used for this purpose.
}
\author{Martin Schaefer}
\seealso{\code{\link{segmentCN}},\code{\link{plot.edira}},\code{\link{find_regions}}, \code{\link{edira_ratios}}}
\examples{
\dontrun{
data(AMLdata)
results <- edira(GE,CN_segmented,GE_ref,CN_ref_segmented)
}
}

\keyword{methods}
