\name{edira_ratios}
\alias{edira_ratios}
\title{Externally Centered Correlation Coefficient and Wilcoxon Test for Equally Directed Abnormalities for ratios data}
\description{
Calculates the externally centered correlation coefficient and performs a Wilcoxon test for equally directed abnormalities of two variables (e.g., gene expression and copy number intensities) between a patient and a reference collective using ratios of patient and a reference data.
}
\usage{
edira_ratios(A, B, references)
}

\arguments{
  \item{A}{list containing ratio data and annotations of variable A for a patient collective. See 'Details' for format.}
  \item{B}{list containing ratio data and annotations of variable B for the same collective represented in \code{A}. See 'Details' for format.}
  \item{references}{Have the ratios for \code{A} and \code{B} been calculated using a real reference collective, or by using, e.g., the median of the patient collective to mimick the normality? 
  either \code{"none"} (no real reference collective for neither input), \code{"only A"} (a real reference collective for B, a mimicked collective for A)
  or \code{"both"} (real reference collectives for both inputs). This is for performing a correction to attenuate effects resulting from the missing reference collective(s).
  Currently implemented only for application to one of the two inputs and meant to use on copy number data exclusively. \code{references=="none"} thus currently has the same effect as \code{references=="only A"}.
  Please only set to \code{"none"} or \code{"only A"} when analyzing copy number as one of the two inputs, and please give the copy number data in argument \code{B}.} 
}
\details{
\code{A} and \code{B} represent ratio data of a patient collective where the values of all patients for a specific locus have been devided by an estimate for the diploid signal for this locus, e.g.,
the median signal of a reference collective. Both must be a list containing a data frame 'data' in which each column contains the data for an individual contained in this collective, and a data frame 'info'
which has a column "chromosome" containing the chromosome number and a column "position" that contains the (middle) position of each measured locus (e.g., probe set) as a single value.

IMPORTANT: The rows of both the data and info objects must be in increasing order of chromosomes and, within chromosomes, of positions.

The measurements in \code{A$data} and \code{B$data} should be obtained under the same laboratory conditions, respectively.

For sensible results, all measurements have to be preprocessed previously (e.g., normalized).
}
\value{
A list is returned containing the following information for each locus:

  \item{chromosome}{chromosome number.}
  \item{position}{(middle) position.}
  \item{eccc}{value of the externally centered correlation coefficient.}
  \item{test}{p-value of the Wilcoxon test for equally directed abnormalities of A and B in the patients compared to the reference collective.}
  \item{quadrant}{quadrant of the median patients' A and B values in the biplot of A and B. Quadrant here is to be understood with respect to the axes defined by the medians of A and B in the reference collective.}
}
\references{Schaefer, M., Schwender, H., Merk, S., Haferlach, C., Ickstadt, K., Dugas, M. (2009), Integrated analysis of copy number alterations and gene expression:
A bivariate assessment of equally directed abnormalities, Bioinformatics 25(24), 3228  3235.
}
\note{This function basically does the same as \code{\link{edira}}, the only difference being that it expects only two data matrices as arguments (a matrix with ratios for each data type).
It is essential that ratio data is supplied, otherwise the method will not work well (the function will try to detect this).

If \code{"reference"} is any other than \code{"both"}, then a transformation is carried out for the input(s) that do not have real reference samples. This is currently implemented only for application
to one of the two inputs and meant to use on copy number data exclusively! To use this feature, please make sure that the copy number data are given in argument \code{B}.
To carry out the transformation, the lociwise mean is calculated for both inputs; if the standard deviation of the lociwise means of input \code{A} is higher, then a weighted mean of the means of both inputs is calculated for each locus and it is given the proper sign in each case (the one of the lociwise mean from \code{B}).
The weights are the standard deviations of the lociwise means. This weighted mean is then used to calculate new ratios, which serve as corrected reference values. The final values to be analyzed are then calculated as ratios of the original inputs and the corrected reference values.
The idea behind this is that when the patient collective is used to mimick reference copy number values (e.g., by imitating a median of reference values by a median of patients)
the mimicked reference signal may not be sufficiently different from the patients' values. By using the mean of both inputs' average signal (with the proper sign) for calculating reference signals for copy number data, this effect may be attenuated when
the variance in the other input is higher. The copy number reference signal in this way may be put farther away from the patients' values, where it would be expected to be if real reference values were available.
This transformation was tested only in experiments analyzing copy number data together with gene expression data and there was able to improve the performance of the method. Note however that it is still experimental!! \code{"reference == both"} corresponds to the published method which is designed for use with
two reference collectives, one for each input.

If the medians of the patient and the reference collective are equal for both of the variables, the corresponding quadrant is determined by sampling.

Copy number data may be processed by a segmentation algorithm to denoise measurements and obtain values that can be assigned directly to data points of
a second data type, e.g., gene expression. The function \code{segmentCN} can be used for this purpose.
}
\author{Martin Schaefer}
\seealso{\code{\link{segmentCN}},\code{\link{plot.edira}},\code{\link{find_regions}}, \code{\link{edira}}
}

\keyword{methods}
