\name{plot.edira}
\alias{plot.edira}
\title{Plotting Function for the Externally Centered Correlation Coefficient and the Wilcoxon Test for Equally Directed Abnormalities}
\description{
Plots values of the externally centered correlation coefficient and p-values of the Wilcoxon test for equally directed abnormalities
in two variables compared to a reference collective, and adds annotation for cytobands
}
\usage{
\method{plot}{edira}(x, type = "test", chr = NULL, pch = 18,
    cyto = TRUE, region_finder = FALSE, regions=NULL, legend = TRUE, ...)
}

\arguments{
  \item{x}{object returned by \code{\link{edira}}.}
  \item{type}{values to be plotted. Can be \code{eccc} (values of the externally centered correlation coefficient), \code{eccc_var} (values of the externally centered correlation coefficient's variant) or \code{test} (p-values of the Wilcoxon test).}
  \item{chr}{number of the chromosome to be plotted. If \code{NULL} (default), chromosomes 1 to 22 are plotted.}
  \item{pch}{plotting symbol.}
  \item{cyto}{logical, only relevant for plotting of a single chromosome. If \code{TRUE}, the beginning of the cytobands is marked in the plot.}
  \item{region_finder}{logical. If \code{TRUE}, regions found by heuristic algorithm stored in \code{regions} are marked yellow.}
  \item{regions}{object returned by \code{\link{find_regions}}, has to be provided if \code{region_finder=TRUE}.}
  \item{legend}{logical. If \code{TRUE}, a legend is added on mouse click after plotting.}
  \item{...}{ignored.}
}
\details{
Values are plotted in different colors: Concordant reductions in both variables are represented by black, concordant increases by red, and discordant abnormalities
by orange and blue. For better visibility, p-values are plotted on a -log10 scale.

For annotation of chromosome and cytoband limits, \code{\link{cytoband}} is used. An equally structured and named object can be provided instead.
}

\references{Schaefer, M., Schwender, H., Merk, S., Haferlach, C., Ickstadt, K., Dugas, M. (2009), Integrated analysis of copy number alterations and gene expression:
A bivariate assessment of equally directed abnormalities, Bioinformatics 25(24), 3228  3235.
}
\author{Martin Schaefer}

\seealso{\code{\link{edira}}, \code{\link{cytoband}}}
\examples{
\dontrun{
data(AMLdata)
results <- edira(GE,CN_segmented,GE_ref,CN_ref_segmented)

regions <- find_regions(results, chr=5)

plot(results, type="eccc", chr=5)
plot(results, type="eccc_var", chr=5)
plot(results, regions=regions, type="test", chr=5, region_finder=TRUE)
}
}

\keyword{hplot}
